#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gdk_imlib.h>

#include "callbacks.h"
#include "interface.h"
#include "rr_main.h"
#include "rr_screen.h"


GtkWidget *fileselection;
GtkWidget *fontselectiondialog;



void
on_screen_destroy                      (GtkObject       *object,
                                        gpointer         user_data)
{
  gtk_main_quit();
}


gboolean
on_screen_button_press_event           (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data)
{
  GtkMenu *menu;
  GdkEventButton *event_button;

    menu = GTK_MENU (create_menu1());

    g_return_val_if_fail (widget != NULL, FALSE);
    g_return_val_if_fail (event != NULL, FALSE);

    /* The "widget" is the menu that was supplied when 
     * gtk_signal_connect_object was called.
     */

    if (event->type == GDK_BUTTON_PRESS)
      {
        event_button = (GdkEventButton *) event;
        if (event_button->button == 3)
          {
            gtk_menu_popup (menu, NULL, NULL, NULL, NULL, 
                            event_button->button, event_button->time);
            return TRUE;
          }
      }

  return FALSE;
}


gboolean
on_draw_area_expose_event              (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data)
{
  return((gboolean)RRScreenRedraw(widget, event, user_data));
}


void
on_face_load1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
  fileselection = create_fileselection ();
  gtk_grab_add(fileselection);
  gtk_widget_show (fileselection);
}


void
on_font_select1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
  fontselectiondialog = create_fontselectiondialog ();
  gtk_grab_add(fontselectiondialog);
  gtk_widget_show (fontselectiondialog);
}


void
on_exit_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
  gtk_main_quit();
}


void
on_ok_button1_clicked                  (GtkButton       *button,
                                        gpointer         user_data)
{
  GdkImlibImage *pic;
  gchar *fname;

  /* --- $B%U%!%$%k%m!<%I%@%$%"%m%0!VN;2r!W(B */
  fname = (gchar*)strdup(gtk_file_selection_get_filename(
		    GTK_FILE_SELECTION(fileselection)));

  /* --- $B%U%!%$%k%M!<%`<hF@(B,$B2hA|%G!<%?FI$_9~$_(B */
  pic = gdk_imlib_load_image(fname);
  if (pic != NULL) {
    ChangeFace(pic);
    gdk_imlib_kill_image(pic);
  }
  free(fname);

  /* --- $B%@%$%"%m%0=*N;(B */
  gtk_widget_destroy(fileselection);

}


void
on_cancel_button1_clicked              (GtkButton       *button,
                                        gpointer         user_data)
{
  /* --- $B%U%!%$%k%m!<%I%@%$%"%m%0!V%-%c%s%;%k!W(B */
  gtk_widget_destroy(fileselection);
}


void
on_ok_button2_clicked                  (GtkButton       *button,
                                        gpointer         user_data)
{
  gchar  *fname;

  /* --- $B%U%)%s%H%@%$%"%m%0!VN;2r!W(B */
  fname = gtk_font_selection_dialog_get_font_name(
	  GTK_FONT_SELECTION_DIALOG(fontselectiondialog));
  RRScreenFontInit(fname);
  RRMainWindowClean();
  free(fname);

  /* --- $B%@%$%"%m%0=*N;(B */
  gtk_widget_destroy(fontselectiondialog);
}


void
on_cancel_button2_clicked              (GtkButton       *button,
                                        gpointer         user_data)
{
  /* --- $B%U%)%s%H%@%$%"%m%0!V%-%c%s%;%k!W(B */
  gtk_widget_destroy(fontselectiondialog);
}


void
on_apply_button1_clicked               (GtkButton       *button,
                                        gpointer         user_data)
{
  gchar  *fname;

  /* --- $B%U%)%s%H%@%$%"%m%0!VE,1~!W(B */
  fname = gtk_font_selection_dialog_get_font_name(
	  GTK_FONT_SELECTION_DIALOG(fontselectiondialog));
  RRScreenFontInit(fname);
  RRMainWindowClean();
  free(fname);
}

